@@ -19,6 +19,7 @@
 
 #include <KAboutData>
 #include <KLocalizedContext>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 
 #include "app/cli.h"
@@ -32,6 +33,7 @@
 #include "validators/secretvalidator.h"
 
 #include "keysmith-features.h"
+#include "stateconfig.h"
 #include "version.h"
 
 /*
@@ -113,13 +115,17 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif
 
     QQmlApplicationEngine engine;
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-
+    KLocalization::setupLocalizedContext(&engine);
     qmlRegisterUncreatableType<app::AddAccountViewModel>("Keysmith.Application",
                                                          1,
                                                          0,
                                                          "AddAccountViewModel",
                                                          QStringLiteral("Should be automatically provided through Keysmith.Application.Navigation signals"));
+
+    qmlRegisterUncreatableType<app::ImportAccountViewModel>("Keysmith.Application", 1, 0, "ImportAccountViewModel",
+        QStringLiteral("Should be automatically provided through Keysmith.Application.Navigation signals")
+    );
+
     qmlRegisterUncreatableType<app::RenameAccountViewModel>("Keysmith.Application",
                                                             1,
                                                             0,
@@ -145,6 +151,11 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                                                                0,
                                                                "AccountsOverviewViewModel",
                                                                QStringLiteral("Should be automatically provided through Keysmith.Navigation signals"));
+    qmlRegisterUncreatableType<app::ScanQRViewModel>("Keysmith.Application",
+                                                     1,
+                                                     0,
+                                                     "ScanQRViewModel",
+                                                     QStringLiteral("Should be automatically provided through Keysmith.Navigation signals"));
     qmlRegisterUncreatableType<app::Navigation>("Keysmith.Application",
                                                 1,
                                                 0,
@@ -167,6 +178,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                                                    "Account",
                                                    QStringLiteral("Use an AccountListModel from the Keysmith singleton to obtain an Account"));
     qmlRegisterType<model::AccountInput>("Keysmith.Models", 1, 0, "ValidatedAccountInput");
+    qmlRegisterType<model::ImportInput>("Keysmith.Models", 1, 0, "ValidatedImportInput");
+    qmlRegisterType<model::ImportInput>("Keysmith.Models", 1, 0, "ValidatedImportInput");
     qmlRegisterType<model::SortedAccountsListModel>("Keysmith.Models", 1, 0, "SortedAccountListModel");
     qmlRegisterType<model::AccountNameValidator>("Keysmith.Validators", 1, 0, "AccountNameValidator");
     qmlRegisterType<validators::EpochValidator>("Keysmith.Validators", 1, 0, "TOTPEpochValidator");
@@ -191,6 +204,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                                                           return new app::CommandLineOptions(cliParser, parseOk);
                                                       });
 
+    qmlRegisterSingletonType<StateConfig>("Keysmith.Application", 1, 0, "StateConfig", [](QQmlEngine *qml, QJSEngine *js) -> QObject * {
+        Q_UNUSED(qml);
+        Q_UNUSED(js);
+
+        return StateConfig::self();
+    });
+
     engine.loadFromModule("org.kde.keysmith", "Main");
     if (engine.rootObjects().isEmpty()) {
         return -1;
